@@ -1,3 +1,4 @@
 if __name__ == '__main__':
     from ._main import main
-    main()
+    code = main()
+    exit(code)
